public struct Country {
  public let code: String

  public init(code: String) {
    self.code = code.uppercased()
  }

  public var emojiFlag: String {
    return code.unicodeScalars
               .map { String(regionalIndicatorSymbol(unicodeScalar: $0)!) }
               .joined()
  }

  func regionalIndicatorSymbol(unicodeScalar: UnicodeScalar) -> UnicodeScalar? {
    let uppercaseA = UnicodeScalar("A")!
    let regionalIndicatorSymbolA = UnicodeScalar("🇦")!
    let distance = unicodeScalar.value - uppercaseA.value
    return UnicodeScalar(regionalIndicatorSymbolA.value + distance)
  }
}

import Foundation

public extension Country {
  public static var all: [Country] {
    return Locale.isoRegionCodes.map { Country(code: $0) }
  }
}
